package com.rshy.project.hy.server;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSON;
import com.google.common.collect.Lists;
import com.rshy.project.hy.baseRe.BaseException;
import com.rshy.project.hy.server.dto.PersonIdentifyBodyDTO;
import com.rshy.project.hy.server.dto.PersonIdentifyDTO;
import com.rshy.project.hy.server.dto.PersonIdentifyImageDTO;
import com.rshy.project.hy.server.vo.PersonIdentifyVO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

/**
 * @author: lileilei
 * @date: 2022/5/2 10:15
 * @description: 省厅应用域常口库接口
 */
@Component
@Slf4j
public class VIIDServer {
    /**
     * 授权凭证请求头
     */
    private static final String HEADERS_KEY = "User-Identify";

    @Value("${viid.url}")
    private String url;
    @Value("${viid.header.userIdentify}")
    private String userIdentify;

    /**
     * @param photo   base64 图片
     * @param timeout
     * @return
     */
    public PersonIdentifyDTO personIdentify(String photo, Integer timeout) {
        PersonIdentifyBodyDTO bodyDTO = new PersonIdentifyBodyDTO().setProfileID("10111").setPriority("1");
        bodyDTO.setFaceImageList(Lists.newArrayList(new PersonIdentifyImageDTO().setImageID("1").setData(photo).setShotTime(String.valueOf(System.currentTimeMillis())).setDeviceID("010101")));
        log.info("浙江省厅统一身份置信接口服务请求入参:{}", JSON.toJSONString(bodyDTO));
        String body = HttpRequest.post(url).header(HEADERS_KEY, userIdentify).body(JSON.toJSONString(bodyDTO)).timeout(timeout).execute().body();
        log.info("浙江省厅统一身份置信接口服务响应信息:{}", body);
        PersonIdentifyVO personIdentifyVO = JSON.parseObject(body, PersonIdentifyVO.class);

        if (personIdentifyVO != null && !"0".equals(personIdentifyVO.getCode())) {
            throw new BaseException(Integer.parseInt(personIdentifyVO.getCode()), personIdentifyVO.getMsg());
        }

        return CollectionUtil.isEmpty(personIdentifyVO.getResults()) ? null : personIdentifyVO.getResults().stream().findFirst().get();
    }
}
