package com.rshy.project.hy.service.impl;


import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.rshy.project.hy.mapper.IdentityMapper;
import com.rshy.project.hy.model.entity.Identity;
import com.rshy.project.hy.service.IdentityService;
import org.springframework.cache.annotation.CachePut;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.cache.annotation.EnableCaching;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author fanqun
 * @since 2022-06-11
 */
@Service
@EnableCaching
public class IdentityServiceImpl extends ServiceImpl<IdentityMapper, Identity> implements IdentityService {

    @Resource
    private IdentityMapper identityMapper;

    @Override
    @Cacheable(value = "identity", key = "#p0", unless = "#result == null")
    public Identity getIdentity(String idNum) {
        LambdaQueryWrapper<Identity> wrapper = new LambdaQueryWrapper<>();
        if (StrUtil.isNotBlank(idNum)) {
            wrapper.eq(Identity::getIdNum, idNum);
        } else {
            return null;
        }
        return identityMapper.selectOne(wrapper);
    }

    @Override
    @Cacheable(value = "identity", key = "#p0", unless = "#result == null")
    public String getIdNum(String barCode) {
        return StrUtil.isBlank(barCode) ? null : identityMapper.getIdNum(barCode);
    }

    @Override
    @CachePut(value = "identity", key = "#p0.idNum", unless = "#result == null")
    public Identity saveOK(Identity identity) {
        if (super.saveOrUpdate(identity))
            return identity;
        return null;
    }
}
