package com.rshy.project.hy.web.controller;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUnit;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.IdcardUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.rshy.project.hy.baseRe.BaseException;
import com.rshy.project.hy.baseRe.ResultCode;
import com.rshy.project.hy.baseRe.Ret;
import com.rshy.project.hy.manager.RshyJkManager;
import com.rshy.project.hy.model.entity.Identity;
import com.rshy.project.hy.model.enums.PassStatusEnum;
import com.rshy.project.hy.server.param.RshyParam;
import com.rshy.project.hy.server.param.RshyQuickParam;
import com.rshy.project.hy.server.vo.RshyVo;
import com.rshy.project.hy.service.IdentityService;
import com.rshy.project.hy.util.PatternUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.Future;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

/**
 * @ProjectName: rshy
 * @Package: com.rshy.project.hy.web.controller
 * @ClassName: RshyController
 * @Author: shihongbo
 * @Description:
 * @Date: 2022/3/2 15:22
 * @Version: 1.0
 */
@RestController
@Api(tags = "人身核验控制层")
@RequestMapping("/rshy")
@Slf4j
public class RshyController {
    @Resource
    private RshyJkManager rshyJkManager;
    @Resource
    private IdentityService identityService;

    @GetMapping(value = "/version")
    public String version() {
        return "1.2.4.220614";
    }

    @ApiOperation("普通核验模式")
    //@NoRepeatSubmit
    @PostMapping("getRyhyInfo")
    public Ret<RshyVo> getRyhyInfo(@RequestBody RshyParam rshyParam) {
        if (StringUtils.isNotBlank(rshyParam.getSfzh()) && !IdcardUtil.isValidCard(rshyParam.getSfzh()) && !PatternUtil.isIDNumber(rshyParam.getSfzh())) {
            log.error("无效的身份证号码");
            //return Ret.error(ResultCode.INVALID_ID_NUMBER);
            throw new BaseException(ResultCode.INVALID_ID_NUMBER);
        }


        if (StrUtil.isEmpty(rshyParam.getPhoto())) {
            log.error("缺少人员照片参数");
            //return Ret.error(ResultCode.MISSING_PARAMETER_PHOTO);
            throw new BaseException(ResultCode.MISSING_PARAMETER_PHOTO);
        }


        DateTime time1 = DateTime.now();

        log.info("普通核验接口请求参数：{}", JSON.toJSONString(rshyParam));

        RshyVo rshyVo = new RshyVo().setPassStatus(PassStatusEnum.NORMAL_TRAFFIC);
        String sfz = rshyParam.getSfzh();
        if (StrUtil.isNotBlank(rshyParam.getBarCode())) {
            sfz = identityService.getIdNum(rshyParam.getBarCode());
        }
        if (StrUtil.isNotBlank(sfz)) {
            Identity identity = identityService.getIdentity(sfz);
            if (identity != null) {
                rshyVo.setXm(identity.getName()).setSfzh(identity.getIdNum()).setPhone(identity.getPhone());
                rshyParam.setSfzh(identity.getIdNum());
                rshyParam.setIdentity(identity);
            }
        }
        try {
            //RshyVo rshyVo = rshyJkManager.getRshyInfo(rshyParam);
            Future<RshyVo> future = rshyJkManager.getRshyInfo(rshyParam);
            rshyVo = future.get(rshyParam.getTimeout() * 1000 - 100, TimeUnit.MILLISECONDS);
        } catch (InterruptedException | ExecutionException e) {
            log.error("普通核验接口异常: {}", e.getMessage());
            //e.printStackTrace();
        } catch (TimeoutException e) {
            log.error("普通核验接口异常: 等待超时");
        } catch (Exception e) {
            throw new BaseException();
        }
        log.info("普通核验响应内容：{}", JSON.toJSONString(rshyVo));
        System.out.println("普通核验接口用时: " + DateUtil.between(time1, DateTime.now(), DateUnit.MS) + "毫秒\n");
        return Ret.success(rshyVo);
    }

    @ApiOperation("人脸快速核验模式")
    @PostMapping("getQuickRyhyInfo")
    public Ret<RshyVo> getQuickRyhyInfo(@RequestBody RshyQuickParam rshyQuickParam) {
        RshyVo rshyVo = rshyJkManager.getQuickRyhyInfo(rshyQuickParam);
        log.info("快速核验响应内容：{}", JSON.toJSONString(rshyVo));
        return Ret.success(rshyVo);
    }
}
